		'use strict';

		let mediaRecorder;
		let recordedBlobs;
		const constraints = {
			audio: true,
			video: false
		};

		//Auxillary functions
		let downloadButton = document.querySelector('button#download');
		downloadButton.onclick = download;

		//Init test example
		if (localStorage.getItem('web_rtc_permission') === 'true') {
			init();
		} else {
			window.addEventListener('storage', storage_event, false);
		}

		function storage_event(e) {
			if (e.key === 'web_rtc_permission') {
				init();
			}
		}

		function init() {
			writeToLog('Start recording procedure');
			navigator.mediaDevices.getUserMedia(constraints).
				then(handleSuccess).catch(handleError);

			setTimeout(() => {
				startRecording();
			}, 100);

			setTimeout(() => {
				stopRecording();
				downloadButton.disabled = false;
			}, 20000);
		}

		function handleSuccess(stream) {
			console.log('getUserMedia() got stream: ', stream);
			window.stream = stream;
		}

		function handleError(error) {
			console.log('navigator.getUserMedia error: ', error);
		}

		function handleDataAvailable(event) {
			if (event.data && event.data.size > 0) {
				writeToLog('blob inserted!');
				recordedBlobs.push(event.data);
			}
		}

		function handleStop(event) {
			console.log('Recorder stopped: ', event);
		}

		function startRecording() {
			writeToLog('Start recording');
			recordedBlobs = [];
			let options = { mimeType: 'audio/mpeg' };
			if (!window.MediaRecorder.isTypeSupported(options.mimeType)) {
				console.log(options.mimeType + ' is not Supported');
				options = { mimeType: '' };
			}
			try {
				mediaRecorder = new window.MediaRecorder(window.stream, options);
			} catch (e) {
				console.error('Exception while creating MediaRecorder: ' + e);
				alert('Exception while creating MediaRecorder: '
					+ e + '. mimeType: ' + options.mimeType);
				return;
			}
			console.log('Created MediaRecorder', mediaRecorder, 'with options', options);
			mediaRecorder.onstop = handleStop;
			mediaRecorder.ondataavailable = handleDataAvailable;
			mediaRecorder.start(10); // collect 10ms of data
			console.log('MediaRecorder started', mediaRecorder);
		}

		function stopRecording() {
			mediaRecorder.stop();
			console.log('Recorded Blobs: ', recordedBlobs);
			writeToLog('Stopped recording!');
		}

		function writeToLog(text) {
			document.getElementById('consoleOutput').innerHTML = text;
		}

		function download() {
			let blob = new Blob(recordedBlobs, { type: 'audio/mpeg' });
			let url = window.URL.createObjectURL(blob);
			let a = document.createElement('a');
			a.style.display = 'none';
			a.href = url;
			a.download = 'SOURCE.mp4';
			document.body.appendChild(a);
			a.click();
			setTimeout(function () {
				document.body.removeChild(a);
				window.URL.revokeObjectURL(url);
			}, 100);
		}